@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -81,9 +82,9 @@ typedef enum {
 } scan_stat;
 
 typedef struct _grn_scan_info scan_info;
-typedef grn_bool (*grn_scan_info_each_arg_callback)(grn_ctx *ctx,
-                                                    grn_obj *obj,
-                                                    void *user_data);
+typedef bool (*grn_scan_info_each_arg_callback)(grn_ctx *ctx,
+                                                grn_obj *obj,
+                                                void *user_data);
 
 void
 grn_expr_init_from_env(void);
@@ -95,7 +96,7 @@ grn_expr_set_query_options(grn_ctx *ctx, grn_obj *expr, grn_obj *query_options);
 
 scan_info **
 grn_scan_info_build(
-  grn_ctx *ctx, grn_obj *expr, int *n, grn_operator op, grn_bool record_exist);
+  grn_ctx *ctx, grn_obj *expr, int *n, grn_operator op, bool record_exist);
 
 scan_info *
 grn_scan_info_open(grn_ctx *ctx, int start);
@@ -165,7 +166,7 @@ int
 grn_scan_info_get_quorum_threshold(scan_info *si);
 void
 grn_scan_info_set_quorum_threshold(scan_info *si, int quorum_threshold);
-grn_bool
+bool
 grn_scan_info_push_arg(grn_ctx *ctx, scan_info *si, grn_obj *arg);
 grn_obj *
 grn_scan_info_get_arg(grn_ctx *ctx, scan_info *si, int i);
@@ -186,7 +187,7 @@ grn_expr_alloc_const(grn_ctx *ctx, grn_obj *expr);
 grn_rc
 grn_ctx_expand_stack(grn_ctx *ctx);
 
-grn_bool
+bool
 grn_expr_is_simple_function_call(grn_ctx *ctx, grn_obj *expr);
 grn_obj *
 grn_expr_simple_function_call_get_function(grn_ctx *ctx, grn_obj *expr);
@@ -195,7 +196,7 @@ grn_expr_simple_function_call_get_arguments(grn_ctx *ctx,
                                             grn_obj *expr,
                                             grn_obj *arguments);
 
-grn_bool
+bool
 grn_expr_is_module_list(grn_ctx *ctx, grn_obj *expr);
 unsigned int
 grn_expr_module_list_get_n_modules(grn_ctx *ctx, grn_obj *expr);
